==> aws-cdk-lib-2.0.0-rc.20-sources.jar: software/amazon/awscdk/services/lambda/LayerVersionAttributes.java <==
package software.amazon.awscdk.services.lambda;

/**
 * (experimental) Properties necessary to import a LayerVersion.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.31.0 (build 6fa403d)", date = "2021-09-01T10:26:32.167Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.$Module.class, fqn = "aws-cdk-lib.aws_lambda.LayerVersionAttributes")
@software.amazon.jsii.Jsii.Proxy(LayerVersionAttributes.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
public interface LayerVersionAttributes extends software.amazon.jsii.JsiiSerializable {

    /**
     * (experimental) The ARN of the LayerVersion.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    @org.jetbrains.annotations.NotNull java.lang.String getLayerVersionArn();

    /**
     * (experimental) The list of compatible runtimes with this Layer.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable java.util.List<software.amazon.awscdk.services.lambda.Runtime> getCompatibleRuntimes() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link LayerVersionAttributes}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link LayerVersionAttributes}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static final class Builder implements software.amazon.jsii.Builder<LayerVersionAttributes> {
        private java.lang.String layerVersionArn;
        private java.util.List<software.amazon.awscdk.services.lambda.Runtime> compatibleRuntimes;

        /**
         * Sets the value of {@link LayerVersionAttributes#getLayerVersionArn}
         * @param layerVersionArn The ARN of the LayerVersion. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder layerVersionArn(java.lang.String layerVersionArn) {
            this.layerVersionArn = layerVersionArn;
            return this;
        }

        /**
         * Sets the value of {@link LayerVersionAttributes#getCompatibleRuntimes}
         * @param compatibleRuntimes The list of compatible runtimes with this Layer.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @SuppressWarnings("unchecked")
        public Builder compatibleRuntimes(java.util.List<? extends software.amazon.awscdk.services.lambda.Runtime> compatibleRuntimes) {
            this.compatibleRuntimes = (java.util.List<software.amazon.awscdk.services.lambda.Runtime>)compatibleRuntimes;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link LayerVersionAttributes}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public LayerVersionAttributes build() {
            return new Jsii$Proxy(layerVersionArn, compatibleRuntimes);
        }
    }

    /**
     * An implementation for {@link LayerVersionAttributes}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements LayerVersionAttributes {
        private final java.lang.String layerVersionArn;
        private final java.util.List<software.amazon.awscdk.services.lambda.Runtime> compatibleRuntimes;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.layerVersionArn = software.amazon.jsii.Kernel.get(this, "layerVersionArn", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.compatibleRuntimes = software.amazon.jsii.Kernel.get(this, "compatibleRuntimes", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.lambda.Runtime.class)));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        @SuppressWarnings("unchecked")
        protected Jsii$Proxy(final java.lang.String layerVersionArn, final java.util.List<? extends software.amazon.awscdk.services.lambda.Runtime> compatibleRuntimes) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.layerVersionArn = java.util.Objects.requireNonNull(layerVersionArn, "layerVersionArn is required");
            this.compatibleRuntimes = (java.util.List<software.amazon.awscdk.services.lambda.Runtime>)compatibleRuntimes;
        }

        @Override
        public final java.lang.String getLayerVersionArn() {
            return this.layerVersionArn;
        }

        @Override
        public final java.util.List<software.amazon.awscdk.services.lambda.Runtime> getCompatibleRuntimes() {
            return this.compatibleRuntimes;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("layerVersionArn", om.valueToTree(this.getLayerVersionArn()));
            if (this.getCompatibleRuntimes() != null) {
                data.set("compatibleRuntimes", om.valueToTree(this.getCompatibleRuntimes()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("aws-cdk-lib.aws_lambda.LayerVersionAttributes"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            LayerVersionAttributes.Jsii$Proxy that = (LayerVersionAttributes.Jsii$Proxy) o;

            if (!layerVersionArn.equals(that.layerVersionArn)) return false;
            return this.compatibleRuntimes != null ? this.compatibleRuntimes.equals(that.compatibleRuntimes) : that.compatibleRuntimes == null;
        }

        @Override
        public final int hashCode() {
            int result = this.layerVersionArn.hashCode();
            result = 31 * result + (this.compatibleRuntimes != null ? this.compatibleRuntimes.hashCode() : 0);
            return result;
        }
    }
}

==> aws-cdk-lib-2.10.0-sources.jar: software/amazon/awscdk/services/lambda/LayerVersionAttributes.java <==
package software.amazon.awscdk.services.lambda;

/**
 * Properties necessary to import a LayerVersion.
 * <p>
 * Example:
 * <p>
 * <blockquote><pre>
 * // The code below shows an example of how to instantiate this type.
 * // The values are placeholders you should change.
 * import software.amazon.awscdk.services.lambda.*;
 * Runtime runtime;
 * LayerVersionAttributes layerVersionAttributes = LayerVersionAttributes.builder()
 *         .layerVersionArn("layerVersionArn")
 *         // the properties below are optional
 *         .compatibleRuntimes(List.of(runtime))
 *         .build();
 * </pre></blockquote>
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.52.1 (build 5ccc8f6)", date = "2022-01-29T04:34:11.226Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.$Module.class, fqn = "aws-cdk-lib.aws_lambda.LayerVersionAttributes")
@software.amazon.jsii.Jsii.Proxy(LayerVersionAttributes.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface LayerVersionAttributes extends software.amazon.jsii.JsiiSerializable {

    /**
     * The ARN of the LayerVersion.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getLayerVersionArn();

    /**
     * The list of compatible runtimes with this Layer.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.util.List<software.amazon.awscdk.services.lambda.Runtime> getCompatibleRuntimes() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link LayerVersionAttributes}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link LayerVersionAttributes}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<LayerVersionAttributes> {
        java.lang.String layerVersionArn;
        java.util.List<software.amazon.awscdk.services.lambda.Runtime> compatibleRuntimes;

        /**
         * Sets the value of {@link LayerVersionAttributes#getLayerVersionArn}
         * @param layerVersionArn The ARN of the LayerVersion. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder layerVersionArn(java.lang.String layerVersionArn) {
            this.layerVersionArn = layerVersionArn;
            return this;
        }

        /**
         * Sets the value of {@link LayerVersionAttributes#getCompatibleRuntimes}
         * @param compatibleRuntimes The list of compatible runtimes with this Layer.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @SuppressWarnings("unchecked")
        public Builder compatibleRuntimes(java.util.List<? extends software.amazon.awscdk.services.lambda.Runtime> compatibleRuntimes) {
            this.compatibleRuntimes = (java.util.List<software.amazon.awscdk.services.lambda.Runtime>)compatibleRuntimes;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link LayerVersionAttributes}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public LayerVersionAttributes build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link LayerVersionAttributes}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements LayerVersionAttributes {
        private final java.lang.String layerVersionArn;
        private final java.util.List<software.amazon.awscdk.services.lambda.Runtime> compatibleRuntimes;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.layerVersionArn = software.amazon.jsii.Kernel.get(this, "layerVersionArn", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.compatibleRuntimes = software.amazon.jsii.Kernel.get(this, "compatibleRuntimes", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.lambda.Runtime.class)));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        @SuppressWarnings("unchecked")
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.layerVersionArn = java.util.Objects.requireNonNull(builder.layerVersionArn, "layerVersionArn is required");
            this.compatibleRuntimes = (java.util.List<software.amazon.awscdk.services.lambda.Runtime>)builder.compatibleRuntimes;
        }

        @Override
        public final java.lang.String getLayerVersionArn() {
            return this.layerVersionArn;
        }

        @Override
        public final java.util.List<software.amazon.awscdk.services.lambda.Runtime> getCompatibleRuntimes() {
            return this.compatibleRuntimes;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("layerVersionArn", om.valueToTree(this.getLayerVersionArn()));
            if (this.getCompatibleRuntimes() != null) {
                data.set("compatibleRuntimes", om.valueToTree(this.getCompatibleRuntimes()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("aws-cdk-lib.aws_lambda.LayerVersionAttributes"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            LayerVersionAttributes.Jsii$Proxy that = (LayerVersionAttributes.Jsii$Proxy) o;

            if (!layerVersionArn.equals(that.layerVersionArn)) return false;
            return this.compatibleRuntimes != null ? this.compatibleRuntimes.equals(that.compatibleRuntimes) : that.compatibleRuntimes == null;
        }

        @Override
        public final int hashCode() {
            int result = this.layerVersionArn.hashCode();
            result = 31 * result + (this.compatibleRuntimes != null ? this.compatibleRuntimes.hashCode() : 0);
            return result;
        }
    }
}
